==> maemoapp_1.0.1-20111222.tar.gz: maemoapp-1.0.1/src/opt/maemoapp/Script/Script.Public.js <==




/****** Main ********/
function doScaleBtns(strType){
    if (strType=='Main'){
        $('MainContent').style.display='block';
        $('MainButtons').className = 'MainButtons';
        $('MainContent').style.display='none';
        
        
        go('UI.html')
    }else{
        for (var i=1;i<=4;i++){ $('MainBtn_'+i).className = 'Button Left'; }
        $('MainBtn_'+strType).className = 'Button Left BtnClick';
        
        setTimeout('doLoadMainContent()',800);
    }
    
    $('DownloadApps').style.display='none';
    $('SearchPackage').style.display='none';
    $('DebugApps').style.display='none';
    $('AllMaemoUsers').style.display='none';

}

function doLoadMainContent(){
    $('MainButtons').className = 'MainButtons ScaleBtns';
    $('MainContent').style.display='block';
}

function doLoginOrLogout(){
    $('MainButtons').style.display='none';
    $('MainContent').style.display='none';
    $('LoginFrame').style.display='block';
    
}

function doAccountLogin(){
    var tmpUserid = $('login_userid').value;
    var tmpPassword = $('login_password').value;
    
    go('UI.html#account_login_'+tmpUserid+'_'+tmpPassword);
    setTimeout('doParseLogin()',1000);
}


VAR_USERID = 0;
VAR_USERNAME = '';
VAR_PASSWORD = '';
function doParseLogin(){
    var tmpRe = getFileContent('cache/account/session.txt');
    
    if (tmpRe){
        tmpRe = tmpRe.split('|');
        $('username').innerHTML = tmpRe[1];
        
        VAR_USERID = tmpRe[0];
        VAR_USERNAME = tmpRe[1];
        VAR_PASSWORD = tmpRe[2];
        VAR_PASSWORD = VAR_PASSWORD.substr(0, 16)
        
        doHideLoginFrm();
    }
}

function doAccountLogout(){
    go('UI.html#account_logout_none');
    $('username').innerHTML = 'Guest';
    doHideLoginFrm();
}

function doHideLoginFrm(){
    $('MainButtons').style.display='block';
    $('MainContent').style.display='block';
    $('LoginFrame').style.display='none';
    
}

function doLoadMessages(){
    var tmpRe = getFileContent('cache/account/message.txt');
    
    if (tmpRe){
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('MessageList').innerHTML = '';
        for(var i=0; i < (tmpRe.length); i++){
        
            tmpHTML  = '<div class="Item Left" onclick="doReplyMessage('+tmpRe[i]['m_id']+', '+tmpRe[i]['userid']+')">['+tmpRe[i]['m_tim']+'] '+tmpRe[i]['username']+' say \'Hi\' to you, Click here to reply.</div>';
            tmpHTML += '<div class="Hide Left" id="MsgFrm_'+tmpRe[i]['m_id']+'">'+tmpRe[i]['m_remark']+'</div>';
            tmpHTML += '<div class="Hide Left" id="ReplyMsgFrm_'+tmpRe[i]['m_id']+'"></div>';
            
            $('MessageList').innerHTML += tmpHTML;
        }
    }
}

function doShowMessages(){
    
    if ($('FrameCenter').style.display == 'none'){
        $('FrameCenter').style.display='block';
        $('MessageList').style.display='none';
        $('FrameBottom').style.height='30px';
        
        $('NewMessage').innerHTML = '[Tip] Click here to view system message and user say hi.';
    }else{
        $('FrameCenter').style.display='none';
        $('MessageList').style.display='block';
        $('FrameBottom').style.height='360px';
        
        $('NewMessage').innerHTML = '[Tip] Click here to hidden message ui.';
    }
}

function doReplyMessage(strID, strUserid){
    if ($('ReplyMsgFrm_'+strID).style.display == 'block'){
        $('MsgFrm_'+strID).style.display='none';
        $('ReplyMsgFrm_'+strID).style.display='none';
    }else{
        $('MsgFrm_'+strID).style.display='block';
        $('ReplyMsgFrm_'+strID).style.display='block';
        
        $('ReplyMsgFrm_'+strID).innerHTML = '';
        tmpHTML  = '    <div class="Left">';
        tmpHTML += '        Please input remark, max 140 word.';
        tmpHTML += '        <form id="frm_post_'+strID+'" name="frm_post_'+strID+'" target="hide_iframe_'+strID+'" action="http://www.maemoapp.com/api/message.asp" method="post">';
        tmpHTML += '        <input type="hidden" name="action" value="sayhi">';
        tmpHTML += '        <input type="hidden" name="userid" value="'+VAR_USERID+'">';
        tmpHTML += '        <input type="hidden" name="password" value="'+VAR_PASSWORD+'">';
        tmpHTML += '        <input type="hidden" name="m_userid" value="'+strUserid+'">';
        tmpHTML += '        <textarea name="remark" style="width:560px;height:200px;"></textarea>';
        tmpHTML += '        </form>';
        tmpHTML += '        <iframe class="hide" id="hide_iframe_'+strID+'" name="hide_iframe_'+strID+'" width="560" height="50" src="about:blank"></iframe>';
        tmpHTML += '    </div>';
        tmpHTML += '    <div class="Right">';
        tmpHTML += '        <div class="FrmSubmit Item Right" onclick="javascript:$(\'frm_post_'+strID+'\').submit();$(\'ReplyMsgFrm_'+strID+'\').style.display=\'none\';">';
        tmpHTML += '            Submit';
        tmpHTML += '        </div>';
        tmpHTML += '    </div>';
        $('ReplyMsgFrm_'+strID).innerHTML += tmpHTML;
    }
}


/*   download apps   */
var VarSelectClassID = 0;
var VarClassOrderBy = 'new';
var VarSearchKeyword = '';

function doDownloadApps(){
    $('DownloadApps').style.display='block';
    
    $('AppClass').style.display='block';
    $('DownloadAppList').style.display='none';
    $('AppClassSummary').style.display='none';
    
}

function doSearchApp(){
    var tmpSearchKeyword = $('SearchKeyword').value;
    VarSearchKeyword = tmpSearchKeyword;
    $('AppClass').style.display='none';
    $('DownloadAppList').style.display='block';
    $('AppClassSummary').style.display='block';
    
    $('SelectClass').innerHTML = 'Search App: '+tmpSearchKeyword;
    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
    
    
    go('UI.html#downloadapps_searchapp_'+tmpSearchKeyword);
    setTimeout('doLoadAppList(false,true)',100);
}

function doAppList(strObj, strClassID){
    $('AppClass').style.display='none';
    $('DownloadAppList').style.display='block';
    $('AppClassSummary').style.display='block';
    
    $('SelectClass').innerHTML = 'Select Class: '+strObj.innerText;
    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
    VarSelectClassID = strClassID;
    VarClassOrderBy = 'new';
    
    setTimeout('doLoadAppList()',100);
}

function doDownloadApp(strDid){
    go('UI.html#downloadapps_downloadapp_'+VarSelectClassID+'_'+VarClassOrderBy+'_'+strDid);
}

function doLoadAppList(strReload, strSearch){
    if (strSearch){
        var tmpRe = getFileContent('cache/apps/search_'+VarSearchKeyword+'.txt');
    }else{
        var tmpRe = getFileContent('cache/apps/class'+VarSelectClassID+'_'+VarClassOrderBy+'.txt');
    }
    if (!tmpRe){
        if ((strReload) || (strSearch)){
            $('DownloadAppList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load apps.</div>';
        }else{
            go('UI.html#downloadapps_loadapps_'+VarSelectClassID+'_'+VarClassOrderBy);
            doLoadAppList(true);
        }
    }else{
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('DownloadAppList').innerHTML = '';
        for(var i=0; i < tmpRe.length; i++){
            tmpHTML  = '       <div class="Item Left" onclick="doAppSummary('+tmpRe[i].d_id+');">';
            tmpHTML += '           <div class="AppIcon Left">';
            tmpHTML += '               <img width="26" height="26" src="'+tmpRe[i].d_pic+'">';
            tmpHTML += '           </div>';
            tmpHTML += '           <div class="AppName Left">';
            tmpHTML += '               '+tmpRe[i].d_topic+' (Size:'+tmpRe[i].d_size+'  Down:'+tmpRe[i].d_counter+')';
            tmpHTML += '           </div>';
            tmpHTML += '           <div class="AppBtn Right">';
            tmpHTML += '               [View Details]';
            tmpHTML += '           </div>';
            tmpHTML += '       </div>';
            tmpHTML += '       <div class="AppSummary Left hide" id="AppSummary_'+tmpRe[i].d_id+'">';
            tmpHTML += '           <div class="Remark Left">Translator:'+tmpRe[i].username+' Update: '+tmpRe[i].d_tim+'<br> '+tmpRe[i].d_remark+'</div>';
            tmpHTML += '           <div class="Download Left" onclick="javascript:doDownloadApp('+tmpRe[i].d_id+');"><img src="images/icon_download.jpg"></div>';
            tmpHTML += '       </div>';
            
            $('DownloadAppList').innerHTML += tmpHTML;
        }
    }

}

function AppListOrderBy(strType){
    VarClassOrderBy = strType;
    doLoadAppList();
}

function doAppSummary(strID){
    if ( $('AppSummary_'+strID).style.display == 'block' ){
        $('AppSummary_'+strID).style.display = 'none';
    }else{
        $('AppSummary_'+strID).style.display = 'block';
    }
}


/***********   search packages  ***********/
function doSearchPackage(){
    $('SearchPackage').style.display='block';
    
}

function doSearchPackageSubmit(){
    var tmpSearchKeyword = $('SearchPackageKeyword').value;
    VarSearchKeyword = tmpSearchKeyword;
    
    $('ResultPackageList').style.display='block';
    $('ResultPackageList').innerHTML = '<div class="Item Left">Please wait, searching...</div>';
    
    
    go('UI.html#searchpackage_keyword_'+tmpSearchKeyword);
    setTimeout('doLoadSearchPachageResult()',500);
}

function doLoadSearchPachageResult(){
    $('ResultPackageList').innerHTML = getFileContent('cache/searchpackage/packages.txt');
}

function doInstallPackage(strPackage){
	var tmptrue=window.confirm('Install it?');
	if (tmptrue) {
        go('UI.html#searchpackage_install_'+strPackage);
	}
}


/***********   debug apps   ***********/
function doDebugApps(){
    $('DebugApps').style.display='block';
    $('DebugOutput').style.display='none';
    $('AppList').style.display='block';
    $('AppInfo').style.display='none';
    
    // 载入 apps，若当前页面未reload过，则从cache加载
    go('UI.html#debugapps_load_apps');
    setTimeout('doLoadApps()',1000);
}

function doPrviewAppInfo(strApp, strIcon){
    $('AppIcon').src='file://'+strIcon;
    $('AppName').innerHTML='App Name: '+strApp;
    $('AppNameShow').innerHTML=strApp;
    $('AppRun').href='#debugapps_run_'+strApp;
    
    $('AppList').style.display='none';
    $('AppInfo').style.display='block';
}

function doLoadApps(){
    $('AppList').innerHTML = getFileContent('cache/debugapps/Apps.txt');
}


/***********   All Maemo Users   ***********/

var VarRoom = 4;
var VarTotalUsers = 0;
var VarLastUpdate = '';
var VarMyGPS = '121111.453292,31.269765';
var VarTarGPS = '104.453292,31.269765';
var VarTarUserid = 0;

function doAllMaemoUsers(){
    $('AllMaemoUsers').style.display='block';
    
    $('UseSummary').style.display='block';
    $('AroundUsers').style.display='none';
    $('GPSMapShow').style.display='none';
    
}

function doShowAround(){
    $('UseSummary').style.display='none';
    $('AroundUsers').style.display='block';
    $('GPSMapShow').style.display='none';

    setTimeout('doLoadUsers()',100);
}

function doRefreshUsers(){
    doLoadUsers(false,true);
}

function doLoadUsers(strReload, strRefresh){
    var tmpRe = getFileContent('cache/users/users.txt');
    
    if (strRefresh){ tmpRe = false; }
    
    if (!tmpRe){
        if (strReload){
            $('AroundUserList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load users.</div>';
        }else{
            go('UI.html#allmaemousers_load_users');
            doLoadUsers(true);
        }
    }else{
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('AroundUserList').innerHTML = '';
        for(var i=0; i < (tmpRe.length-1); i++){
        
            tmpHTML  = '<div class="Item" onclick="javascript:doGPSMapShow(\''+tmpRe[i][0]+'\',\''+tmpRe[i][1]+'\',\''+tmpRe[i][4]+'\');">';
            tmpHTML += '    <div class="Username ">'+tmpRe[i][1]+'</div>';
            tmpHTML += '    <div class="Distance">(~= '+tmpRe[i][2]+'m)</div>';
            tmpHTML += '    <div class="LastUpdate">['+tmpRe[i][3]+']</div>';
            tmpHTML += '</div>';
            
            $('AroundUserList').innerHTML += tmpHTML;
        }
        
        VarTotalUsers = tmpRe[tmpRe.length-1][0];
        VarLastUpdate = tmpRe[tmpRe.length-1][1];
        VarMyGPS = tmpRe[tmpRe.length-1][2];
    
        $('TotalUser').innerHTML = VarTotalUsers;
        $('LastUpdate').innerHTML = VarLastUpdate;
    }
}

function doGPSMapShow(strUid, strUsername, strGPS){
    VarTarGPS = strGPS;
    VarTarUserid = strUid;
    $('FindUser').innerHTML = strUsername + ' (uid:'+strUid+')';
    
    $('UseSummary').style.display='none';
    $('AroundUsers').style.display='none';
    $('GPSMapShow').style.display='block';
    
    doInitMap();
}


function doSayHi(){
	var tmpTrue=window.confirm('Confirm say \'Hi\' to this user?');
	if (tmpTrue) {
        go('UI.html#account_sayhi_'+VarTarUserid);
	}
}

function doUpdateGPS(){
	var tmpTrue=window.confirm('Confirm update your gps data to maemoapp.com server?');
	if (tmpTrue) {
        go('UI.html#allmaemousers_update_gps');
	}
}



function doInitMap(){
    
    $('MyGPS').innerHTML = VarMyGPS;
    $('TarGPS').innerHTML = VarTarGPS;
    $('GPSDistance').innerHTML = toDistance(eval('['+VarMyGPS+']'), eval('['+VarTarGPS+']'));
    $('MapRoom').innerHTML = VarRoom;
    
    doMapRoom();
}

function doMapRoom(strType){
    var tmpAPI = 'http://api.map.baidu.com/staticimage?width=400&height=300&center={$center}&markers={$markers}&markerStyles=m,M|m,T&zoom={$zoom}';
    var tmpMaxZoom = 18;
    var tmpMinZoom = 2;
    
    if (strType=='+'){
        if (VarRoom < tmpMaxZoom){ VarRoom++; }
    }else if(strType=='-'){
        if (VarRoom > tmpMinZoom ){ VarRoom--; }
    }
    
    tmpAPI = tmpAPI.replace('{$zoom}', VarRoom);
    tmpAPI = tmpAPI.replace('{$center}', VarTarGPS);
    tmpAPI = tmpAPI.replace('{$markers}', VarMyGPS+'|'+VarTarGPS);
    
    $('MapRoom').innerHTML = VarRoom;
    $('ApiMap').src = tmpAPI;
}

function toDistance(strA, strB){
    var tmpRe = getCalcDistance(strA, strB)
    tmpRe = parseInt(tmpRe);
    if ( tmpRe <= 1000 ){
        tmpRe += 'm';
    }else{
        tmpRe = tmpRe/1000;
        tmpRe += 'km';
    }
    return tmpRe;
}

function getCalcDegree(d){  
    return d*Math.PI/180.0 ;  
} 

function getCalcDistance(f,t){
    var FINAL = 6378137.0
    var flat = getCalcDegree(f[1]) ;  
    var flng = getCalcDegree(f[0]) ;  
    var tlat = getCalcDegree(t[1]) ;  
    var tlng = getCalcDegree(t[0]) ;
      
    var result = Math.sin(flat)*Math.sin(tlat) ;  
    result += Math.cos(flat)*Math.cos(tlat)*Math.cos(flng-tlng) ;  
    return Math.acos(result)*FINAL ;  
}



function go(strURL) { location.href=strURL; setTimeout('doLoadMessages()',1000); }
function $(){return document.getElementById?document.getElementById(arguments[0]):eval(arguments[0]);}

==> maemoapp_1.0.5-20111222.tar.gz: maemoapp-1.0.5/src/opt/maemoapp/Script/Script.Public.js <==




/****** Main ********/
function doScaleBtns(strType){
    if (strType=='Main'){
        $('MainContent').style.display='block';
        $('MainButtons').className = 'MainButtons';
        $('MainContent').style.display='none';
        
        
        go('UI.html')
    }else{
        for (var i=1;i<=4;i++){ $('MainBtn_'+i).className = 'Button Left'; }
        $('MainBtn_'+strType).className = 'Button Left BtnClick';
        
        setTimeout('doLoadMainContent()',800);
    }
    
    $('DownloadApps').style.display='none';
    $('SearchPackage').style.display='none';
    $('DebugApps').style.display='none';
    $('AllMaemoUsers').style.display='none';

}

function doLoadMainContent(){
    $('MainButtons').className = 'MainButtons ScaleBtns';
    $('MainContent').style.display='block';
}

function doLoginOrLogout(){
    $('MainButtons').style.display='none';
    $('MainContent').style.display='none';
    $('LoginFrame').style.display='block';
    
}

function doAccountLogin(){
    var tmpUserid = $('login_userid').value;
    var tmpPassword = $('login_password').value;
    
    go('UI.html#account_login_'+tmpUserid+'_'+tmpPassword);
    setTimeout('doParseLogin()',1000);
}


VAR_USERID = 0;
VAR_USERNAME = '';
VAR_PASSWORD = '';
function doParseLogin(){
    var tmpRe = getFileContent('cache/account/session.txt');
    
    if (tmpRe){
        tmpRe = tmpRe.split('|');
        $('username').innerHTML = tmpRe[1];
        
        VAR_USERID = tmpRe[0];
        VAR_USERNAME = tmpRe[1];
        VAR_PASSWORD = tmpRe[2];
        VAR_PASSWORD = VAR_PASSWORD.substr(0, 16)
        
        doHideLoginFrm();
    }
}

function doAccountLogout(){
    go('UI.html#account_logout_none');
    $('username').innerHTML = 'Guest';
    doHideLoginFrm();
}

function doHideLoginFrm(){
    $('MainButtons').style.display='block';
    $('MainContent').style.display='block';
    $('LoginFrame').style.display='none';
    
}

function doLoadMessages(){
    var tmpRe = getFileContent('cache/account/message.txt');
    
    if (tmpRe){
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('MessageList').innerHTML = '';
        for(var i=0; i < (tmpRe.length); i++){
        
            tmpHTML  = '<div class="Item Left" onclick="doReplyMessage('+tmpRe[i]['m_id']+', '+tmpRe[i]['userid']+')">['+tmpRe[i]['m_tim']+'] '+tmpRe[i]['username']+' say \'Hi\' to you, Click here to reply.</div>';
            tmpHTML += '<div class="Hide Left" id="MsgFrm_'+tmpRe[i]['m_id']+'">'+tmpRe[i]['m_remark']+'</div>';
            tmpHTML += '<div class="Hide Left" id="ReplyMsgFrm_'+tmpRe[i]['m_id']+'"></div>';
            
            $('MessageList').innerHTML += tmpHTML;
        }
    }
}

function doShowMessages(){
    
    if ($('FrameCenter').style.display == 'none'){
        $('FrameCenter').style.display='block';
        $('MessageList').style.display='none';
        $('FrameBottom').style.height='30px';
        
        $('NewMessage').innerHTML = '[Tip] Click here to view system message and user say hi.';
    }else{
        $('FrameCenter').style.display='none';
        $('MessageList').style.display='block';
        $('FrameBottom').style.height='360px';
        
        $('NewMessage').innerHTML = '[Tip] Click here to hidden message ui.';
    }
}

function doReplyMessage(strID, strUserid){
    if ($('ReplyMsgFrm_'+strID).style.display == 'block'){
        $('MsgFrm_'+strID).style.display='none';
        $('ReplyMsgFrm_'+strID).style.display='none';
    }else{
        $('MsgFrm_'+strID).style.display='block';
        $('ReplyMsgFrm_'+strID).style.display='block';
        
        $('ReplyMsgFrm_'+strID).innerHTML = '';
        tmpHTML  = '    <div class="Left">';
        tmpHTML += '        Please input remark, max 140 word.';
        tmpHTML += '        <form id="frm_post_'+strID+'" name="frm_post_'+strID+'" target="hide_iframe_'+strID+'" action="http://www.maemoapp.com/api/message.asp" method="post">';
        tmpHTML += '        <input type="hidden" name="action" value="sayhi">';
        tmpHTML += '        <input type="hidden" name="userid" value="'+VAR_USERID+'">';
        tmpHTML += '        <input type="hidden" name="password" value="'+VAR_PASSWORD+'">';
        tmpHTML += '        <input type="hidden" name="m_userid" value="'+strUserid+'">';
        tmpHTML += '        <textarea name="remark" style="width:560px;height:200px;"></textarea>';
        tmpHTML += '        </form>';
        tmpHTML += '        <iframe class="hide" id="hide_iframe_'+strID+'" name="hide_iframe_'+strID+'" width="560" height="50" src="about:blank"></iframe>';
        tmpHTML += '    </div>';
        tmpHTML += '    <div class="Right">';
        tmpHTML += '        <div class="FrmSubmit Item Right" onclick="javascript:$(\'frm_post_'+strID+'\').submit();$(\'ReplyMsgFrm_'+strID+'\').style.display=\'none\';">';
        tmpHTML += '            Submit';
        tmpHTML += '        </div>';
        tmpHTML += '    </div>';
        $('ReplyMsgFrm_'+strID).innerHTML += tmpHTML;
    }
}


/*   download apps   */
var VarSelectClassID = 0;
var VarClassOrderBy = 'new';
var VarSearchKeyword = '';

function doDownloadApps(){
    $('DownloadApps').style.display='block';
    
    $('AppClass').style.display='block';
    $('DownloadAppList').style.display='none';
    $('AppClassSummary').style.display='none';
    
}

function doSearchApp(){
    var tmpSearchKeyword = $('SearchKeyword').value;
    VarSearchKeyword = tmpSearchKeyword;
    $('AppClass').style.display='none';
    $('DownloadAppList').style.display='block';
    $('AppClassSummary').style.display='block';
    
    $('SelectClass').innerHTML = 'Search App: '+tmpSearchKeyword;
    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
    
    
    go('UI.html#downloadapps_searchapp_'+tmpSearchKeyword);
    setTimeout('doLoadAppList(false,true)',100);
}

function doAppList(strObj, strClassID){
    $('AppClass').style.display='none';
    $('DownloadAppList').style.display='block';
    $('AppClassSummary').style.display='block';
    
    $('SelectClass').innerHTML = 'Select Class: '+strObj.innerText;
    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
    VarSelectClassID = strClassID;
    VarClassOrderBy = 'new';
    
    setTimeout('doLoadAppList()',100);
}

function doDownloadApp(strDid){
    go('UI.html#downloadapps_downloadapp_'+VarSelectClassID+'_'+VarClassOrderBy+'_'+strDid);
}

function doLoadAppList(strReload, strSearch){
    if (strSearch){
        var tmpRe = getFileContent('cache/apps/search_'+VarSearchKeyword+'.txt');
    }else{
        var tmpRe = getFileContent('cache/apps/class'+VarSelectClassID+'_'+VarClassOrderBy+'.txt');
    }
    if (!tmpRe){
        if ((strReload) || (strSearch)){
            $('DownloadAppList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load apps.</div>';
        }else{
            go('UI.html#downloadapps_loadapps_'+VarSelectClassID+'_'+VarClassOrderBy);
            doLoadAppList(true);
        }
    }else{
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('DownloadAppList').innerHTML = '';
        for(var i=0; i < tmpRe.length; i++){
            tmpHTML  = '       <div class="Item Left" onclick="doAppSummary('+tmpRe[i].d_id+');">';
            tmpHTML += '           <div class="AppIcon Left">';
            tmpHTML += '               <img width="26" height="26" src="'+tmpRe[i].d_pic+'">';
            tmpHTML += '           </div>';
            tmpHTML += '           <div class="AppName Left">';
            tmpHTML += '               '+tmpRe[i].d_topic+' (Size:'+tmpRe[i].d_size+'  Down:'+tmpRe[i].d_counter+')';
            tmpHTML += '           </div>';
            tmpHTML += '           <div class="AppBtn Right">';
            tmpHTML += '               [View Details]';
            tmpHTML += '           </div>';
            tmpHTML += '       </div>';
            tmpHTML += '       <div class="AppSummary Left hide" id="AppSummary_'+tmpRe[i].d_id+'">';
            tmpHTML += '           <div class="Remark Left">Translator:'+tmpRe[i].username+' Update: '+tmpRe[i].d_tim+'<br> '+tmpRe[i].d_remark+'</div>';
            tmpHTML += '           <div class="Download Left" onclick="javascript:doDownloadApp('+tmpRe[i].d_id+');"><img src="images/icon_download.jpg"></div>';
            tmpHTML += '       </div>';
            
            $('DownloadAppList').innerHTML += tmpHTML;
        }
    }

}

function AppListOrderBy(strType){
    VarClassOrderBy = strType;
    doLoadAppList();
}

function doAppSummary(strID){
    if ( $('AppSummary_'+strID).style.display == 'block' ){
        $('AppSummary_'+strID).style.display = 'none';
    }else{
        $('AppSummary_'+strID).style.display = 'block';
    }
}


/***********   search packages  ***********/
function doSearchPackage(){
    $('SearchPackage').style.display='block';
    
}

function doSearchPackageSubmit(){
    var tmpSearchKeyword = $('SearchPackageKeyword').value;
    VarSearchKeyword = tmpSearchKeyword;
    
    $('ResultPackageList').style.display='block';
    $('ResultPackageList').innerHTML = '<div class="Item Left">Please wait, searching...</div>';
    
    
    go('UI.html#searchpackage_keyword_'+tmpSearchKeyword);
    setTimeout('doLoadSearchPachageResult()',500);
}

function doLoadSearchPachageResult(){
    $('ResultPackageList').innerHTML = getFileContent('cache/searchpackage/packages.txt');
}

function doInstallPackage(strPackage){
	var tmptrue=window.confirm('Install it?');
	if (tmptrue) {
        go('UI.html#searchpackage_install_'+strPackage);
	}
}


/***********   debug apps   ***********/
function doDebugApps(){
    $('DebugApps').style.display='block';
    $('DebugOutput').style.display='none';
    $('AppList').style.display='block';
    $('AppInfo').style.display='none';
    
    // 载入 apps，若当前页面未reload过，则从cache加载
    go('UI.html#debugapps_load_apps');
    setTimeout('doLoadApps()',1000);
}

function doPrviewAppInfo(strApp, strIcon){
    $('AppIcon').src='file://'+strIcon;
    $('AppName').innerHTML='App Name: '+strApp;
    $('AppNameShow').innerHTML=strApp;
    $('AppRun').href='#debugapps_run_'+strApp;
    
    $('AppList').style.display='none';
    $('AppInfo').style.display='block';
}

function doLoadApps(){
    $('AppList').innerHTML = getFileContent('cache/debugapps/Apps.txt');
}


/***********   All Maemo Users   ***********/

var VarRoom = 4;
var VarTotalUsers = 0;
var VarLastUpdate = '';
var VarMyGPS = '121111.453292,31.269765';
var VarTarGPS = '104.453292,31.269765';
var VarTarUserid = 0;

function doAllMaemoUsers(){
    $('AllMaemoUsers').style.display='block';
    
    $('UseSummary').style.display='block';
    $('AroundUsers').style.display='none';
    $('GPSMapShow').style.display='none';
    
}

function doShowAround(){
    $('UseSummary').style.display='none';
    $('AroundUsers').style.display='block';
    $('GPSMapShow').style.display='none';

    setTimeout('doLoadUsers()',100);
}

function doRefreshUsers(){
    doLoadUsers(false,true);
}

function doLoadUsers(strReload, strRefresh){
    var tmpRe = getFileContent('cache/users/users.txt');
    
    if (strRefresh){ tmpRe = false; }
    
    if (!tmpRe){
        if (strReload){
            $('AroundUserList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load users.</div>';
        }else{
            go('UI.html#allmaemousers_load_users');
            doLoadUsers(true);
        }
    }else{
        tmpRe = eval('tmpRe='+tmpRe);
        
        $('AroundUserList').innerHTML = '';
        for(var i=0; i < (tmpRe.length-1); i++){
        
            tmpHTML  = '<div class="Item" onclick="javascript:doGPSMapShow(\''+tmpRe[i][0]+'\',\''+tmpRe[i][1]+'\',\''+tmpRe[i][4]+'\');">';
            tmpHTML += '    <div class="Username">'+tmpRe[i][1]+'</div>';
            tmpHTML += '    <div class="Distance">(~= '+toDistanceUtil(tmpRe[i][2])+')</div>';
            tmpHTML += '    <div class="LastUpdate">['+tmpRe[i][3]+']</div>';
            tmpHTML += '</div>';
            
            $('AroundUserList').innerHTML += tmpHTML;
        }
        
        VarTotalUsers = tmpRe[tmpRe.length-1][0];
        VarLastUpdate = tmpRe[tmpRe.length-1][1];
        VarMyGPS = tmpRe[tmpRe.length-1][2];
    
        $('TotalUser').innerHTML = VarTotalUsers;
        $('LastUpdate').innerHTML = VarLastUpdate;
    }
}

function doGPSMapShow(strUid, strUsername, strGPS){

    VarTarGPS = strGPS;
    VarTarUserid = strUid;
    $('FindUser').innerHTML = strUsername + ' (uid:'+strUid+')';
    
    $('UseSummary').style.display='none';
    $('AroundUsers').style.display='none';
    $('GPSMapShow').style.display='block';
    
    doInitMap();
}


function doSayHi(){
	var tmpTrue=window.confirm('Confirm say \'Hi\' to this user?');
	if (tmpTrue) {
        go('UI.html#account_sayhi_'+VarTarUserid);
	}
}

function doUpdateGPS(){
	var tmpTrue=window.confirm('Confirm update your gps data to maemoapp.com server?');
	if (tmpTrue) {
        go('UI.html#allmaemousers_update_gps');
	}
}



function doInitMap(){
    
    $('MyGPS').innerHTML = VarMyGPS;
    $('TarGPS').innerHTML = VarTarGPS;
    $('GPSDistance').innerHTML = toDistance(eval('['+VarMyGPS+']'), eval('['+VarTarGPS+']'));
    $('MapRoom').innerHTML = VarRoom;
    
    doMapRoom();
}

function doMapRoom(strType){
    var tmpAPI = 'http://api.map.baidu.com/staticimage?width=400&height=300&center={$center}&markers={$markers}&markerStyles=m,M|m,T&zoom={$zoom}';
    var tmpMaxZoom = 18;
    var tmpMinZoom = 2;
    
    if (strType=='+'){
        if (VarRoom < tmpMaxZoom){ VarRoom++; }
    }else if(strType=='-'){
        if (VarRoom > tmpMinZoom ){ VarRoom--; }
    }
    
    tmpAPI = tmpAPI.replace('{$zoom}', VarRoom);
    tmpAPI = tmpAPI.replace('{$center}', VarTarGPS);
    tmpAPI = tmpAPI.replace('{$markers}', VarMyGPS+'|'+VarTarGPS);
    
    $('MapRoom').innerHTML = VarRoom;
    $('ApiMap').src = tmpAPI;
}

function toDistance(strA, strB){
    var tmpRe = getCalcDistance(strA, strB)
    return toDistanceUtil(tmpRe)
}

function toDistanceUtil(strNum){
    strNum = parseInt(strNum);
    if ( strNum <= 1000 ){
        strNum += 'm';
    }else{
        strNum = strNum/1000;
        strNum = parseInt(strNum);
        strNum += 'km';
    }
    return strNum;
}

function getCalcDegree(d){  
    return d*Math.PI/180.0 ;  
} 

function getCalcDistance(f,t){
    var FINAL = 6378137.0
    var flat = getCalcDegree(f[1]) ;  
    var flng = getCalcDegree(f[0]) ;  
    var tlat = getCalcDegree(t[1]) ;  
    var tlng = getCalcDegree(t[0]) ;
      
    var result = Math.sin(flat)*Math.sin(tlat) ;  
    result += Math.cos(flat)*Math.cos(tlat)*Math.cos(flng-tlng) ;  
    return Math.acos(result)*FINAL ;  
}



function go(strURL) { location.href=strURL; setTimeout('doLoadMessages()',1000); }
function $(){return document.getElementById?document.getElementById(arguments[0]):eval(arguments[0]);}
